/*****************************************************************************/
/*                                                                           */
/*    COPYRIGHT : 5765 - 196                                                 */
/*                5765 - 476                                                 */
/*                5765 - 477                                                 */
/*    @(#)(C) Copyright IBM Corp. 1993, 1995, 1996                           */
/*                                                                           */
/*    ALL RIGHTS RESERVED                                                    */
/*    LICENSED MATERIALS - PROPERTY OF IBM                                   */
/*                                                                           */
/* Product:         NetView Distribution Manager/6000                        */
/*                                                                           */
/* Module:          fndsx.c                                                  */
/*                                                                           */
/* Component:       Scheduler User-Exit Routines                             */
/*                                                                           */
/* Description:     This module contains the Scheduler User Exit Routines    */
/*                  related to Remote Directories section of CF +            */
/*                  target configuration and user configuration user         */
/*                  exits                                                    */
/*                                                                           */
/*                  The following routines are provided:                     */
/*                    - sx_export_dir                                        */
/*                    - sx_unexport_dir                                      */
/*                    - sx_usrexit_trgcfg                                    */
/*                    - sx_usrexit_trgcfg                                    */
/*****************************************************************************/
#include <string.h>                     /* C header                          */
#include <signal.h>                     /* C header                          */
#include <stdio.h>                      /* C header                          */
#include <fcntl.h>                      /* C header                          */
#include <stdlib.h>                     /* C header                          */

#include <fndhdr.h>
#include <fndshrr.h>
#include <fndsx.h>


DC_USHORT sx_export_dir ( REMOTE_DIR   *remote_dir,
                          TRG_INFO  *target_info,
                          DC_LONG      *errcode,
                          DC_USHORT prot)
/*****************************************************************************/
/*                                                                           */
/* Description: This routine executes the export of remote directories       */
/*              specified into CF, before submitting the request, at the     */
/*              server.                                                      */
/*                                                                           */
/*              This routine is called from 1 point in Scheduler (dvashcm.c) */
/*              - sh_inst_req                                                */
/*                                                                           */
/* Parameters:                                                               */
/*            * remote_dir     : remote directory read                       */
/*            * target_info    : structure of target                         */
/*              *errcode       : return code after mk(ch)nfsexp              */
/*              prot           : transport protocol (not used)               */
/*                                                                           */
/* Returns:     0   : Successfull completion                                 */
/*              4   : directory already exported                             */
/*              8   : directory does not exist                               */
/*             12   : generic error encountered exporting the directory      */
/*                                                                           */
/*****************************************************************************/
{

 DC_USHORT  rc;
 rc = DC_OK;

 return(rc);

}   /* sx_export_dir */

DC_USHORT sx_unexport_dir (REMOTE_DIR  *remote_dir,
                          TRG_INFO  *target_info,
                          DC_LONG      *errcode,
                          DC_USHORT prot)
/*****************************************************************************/
/*                                                                           */
/* Description: This routine executes the unexport of remote directories     */
/*              specified into CF, during processing the report, after       */
/*              processing the request                                       */
/*                                                                           */
/*              This routine is called from 1 point in Scheduler (dvashrpt.c)*/
/*              - sh_dcc_rep                                                 */
/*                                                                           */
/* Parameters:                                                               */
/*             *remote_dir     : remote directory read                       */
/*             *target_info    : structure of target                         */
/*              *errcode       : return code after rmnfsexp                  */
/*              prot           : transport protocol (not used)               */
/*                                                                           */
/* Returns:     0   : Successfull completion                                 */
/*              8   : generic error encountered unexporting the directory    */
/*                                                                           */
/*****************************************************************************/
{
 DC_USHORT  rc ;
        rc = DC_OK;
  return(rc);
}   /* sx_unexport_dir */

DC_SHORT  sx_usrexit_trgcfg(const  DC_USHORT             action,
                            const  USRX_TARGET_CONFIG   *in_trg_cfg,
                            USRX_TARGET_CONFIG          *out_trg_config)
/*****************************************************************************/
/* Description: This routine will be called during an add or update command  */
/*              required for a target configuration record.                  */
/*                                                                           */
/*              It can be filled by user code, to set default value of a     */
/*              target configuration record.                                 */
/*              The fields which the product will consider are:              */
/*                                                                           */
/*              - description      : Descriptive information.                */
/*              - target_os        : OS of target (OS/2, AIX, DOS...).       */
/*              - password         : Target password.                        */
/*              - lan_addr         : LAN card burned-in address.             */
/*              - cust             : Customer name.                          */
/*              - contact          : Contact name.                           */
/*              - contact_phone    : Contact phone number.                   */
/*              - manager          : Owning manager's name.                  */
/*              - manager_addr     : Owning manager's mail address.          */
/*              - num_hw_parm      : Number of hardware parameters.          */
/*              - hw_parm          : Hardware parameter array.               */
/*              - num_inst_parm    : Number of installation parameters.      */
/*              - inst_parm        : Installation parameter array.           */
/*                                                                           */
/*                                                                           */
/* Parameters:                                                               */
/*              action         : ADD_CFG or UPD_CFG according to the         */
/*                               executing command.                          */
/*              in_trg_config  : input structure of target configuration     */
/*                               record.                                     */
/*              out_trg_config : output structure of target configuration    */
/*                               record which can be filled with user-exit   */
/*                               default values.                             */
/*                                                                           */
/* Returns:     0   : Successfull completion                                 */
/*                                                                           */
/*****************************************************************************/
{
  DC_USHORT  rc;

  rc = DC_OK;

  return(rc);
}   /* sx_usrexit_trgcfg */


DC_SHORT  sx_usrexit_usrcfg(const  DC_USHORT        action,
                            const  USRX_USER_DEF   *in_usr_cfg,
                            USRX_USER_DEF          *out_usr_def)
/*****************************************************************************/
/* Description: This routine will be called during an add or update command  */
/*              required for a user configuration record.                    */
/*                                                                           */
/*              It can be filled by user code, to set default value of a     */
/*              user configuration record.                                   */
/*              The fields which the product will consider are:              */
/*                                                                           */
/*              - description      : Descriptive information.                */
/*                                                                           */
/*                                                                           */
/* Parameters:                                                               */
/*              action         : ADD_CFG or UPD_CFG according to the         */
/*                               executing command.                          */
/*              in_usr_def     : input structure of user configuration       */
/*                               record.                                     */
/*              out_usr_def    : output structure of user configuration      */
/*                               record which can be filled with user-exit   */
/*                               default values.                             */
/*                                                                           */
/* Returns:     0   : Successfull completion                                 */
/*                                                                           */
/*****************************************************************************/
{
  DC_USHORT  rc;

  rc = DC_OK;

  return(rc);
}   /* sx_usrexit_usrcfg */

/* fndsx.c */
