/*****************************************************************************/
/*                                                                           */
/*    COPYRIGHT : 5765 - 196                                                 */
/*    (C) COPYRIGHT IBM CORP 1993                                            */
/*    ALL RIGHTS RESERVED                                                    */
/*    LICENSED MATERIALS - PROPERTY OF IBM                                   */
/*                                                                           */
/* Product:         NetView Distribution Manager/6000                        */
/*                                                                           */
/* Module:          FNDSX.H                                                  */
/*                                                                           */
/* Component:       Server User Exits Header File                            */
/*                                                                           */
/* Description:     This module contains the function prototypes and         */
/*                  data definitions related to the functions contained      */
/*                  in fndsx.c file.                                         */
/*                                                                           */
/*                                                                           */
/*****************************************************************************/


DC_USHORT sx_export_dir ( REMOTE_DIR  *remote_dir,
                          TRG_INFO *target_info,
                          DC_LONG     *errcode,
                          DC_USHORT prot);
/*****************************************************************************/
/*                                                                           */
/* Description: This routine executes the export of remote directories       */
/*              specified into CF, before submitting the request, at the     */
/*              server.                                                      */
/*                                                                           */
/*              This routine is called from 1 point in Scheduler (dvashcm.c) */
/*              - sh_inst_req                                                */
/*                                                                           */
/* Parameters:                                                               */
/*             *remote_dir     : remote directory read                       */
/*             *target_info    : structure of target                         */
/*              *errcode       : return code after mk(ch)nfsexp              */
/*              prot           : transport protocol (used on OS/2 platform)  */
/*                                       1 for TCP/IP                        */
/*                                       3 for NETBIOS                       */
/*                                       4 for IPX                           */
/*                                                                           */
/* Returns:     0   : Successfull completion                                 */
/*              4   : directory already exported                             */
/*              8   : directory does not exist                               */
/*             12   : generic error encountered exporting the directory      */
/*                                                                           */
/*****************************************************************************/

DC_USHORT sx_unexport_dir ( REMOTE_DIR  *remote_dir,
                            TRG_INFO    *target_info,
                            DC_LONG      *errcode,
                            DC_USHORT prot);
/*****************************************************************************/
/*                                                                           */
/* Description: This routine executes the unexport of remote directories     */
/*              specified into CF, during processing the report, after       */
/*              processing the request                                       */
/*                                                                           */
/*              This routine is called from 1 point in Scheduler (dvashrpt.c)*/
/*              - sh_dcc_rep                                                 */
/*                                                                           */
/* Parameters:                                                               */
/*             *remote_dir     : remote directory read                       */
/*             *target_info    : structure of target                         */
/*              *errcode       : return code after rmnfsexp                  */
/*              prot           : transport protocol (used on OS/2 platform)  */
/*                                       1 for TCP/IP                        */
/*                                       3 for NETBIOS                       */
/*                                       4 for IPX                           */
/*                                                                           */
/* Returns:     0   : Successfull completion                                 */
/*              8   : generic error encountered unexporting the directory    */
/*                                                                           */
/*****************************************************************************/


/*****************************************************************************/
/* Structure: USRX_INST_PARM                                                 */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure stores one <parameter> = <value> pair.                   */
/*                                                                           */
/* Fields:                                                                   */
/*   prm                                                                     */
/*     parameter                                                             */
/*   value                                                                   */
/*     value of parameter                                                    */
/*****************************************************************************/
typedef struct usrx_inst_parm
{
  DC_CHAR    prm[DVA_TOKEN_LEN];
  DC_CHAR    value[DVA_MAX_TOKN_TXT];
} USRX_INST_PARM;

/*****************************************************************************/
/* Structure: USRX_HW_PARM                                                   */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure holds hardware parameters in the target                  */
/*   configuration record.                                                   */
/*                                                                           */
/* Fields:                                                                   */
/*   pname                                                                   */
/*     string identifying the parameter                                      */
/*   pval                                                                    */
/*     value of parameter                                                    */
/*****************************************************************************/
typedef struct usrx_hw_parm
{
  DC_CHAR    pname[DVA_CFGNAME_LEN];
  DC_CHAR    pval[DVA_CFGNAME_LEN];
} USRX_HW_PARM;

/*****************************************************************************/
/* Structure: USRX_NETWORK_CFG                                               */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure defines the target protocol configuration.               */
/*   These information aren't cached in memory.                              */
/*                                                                           */
/* Fields:                                                                   */
/*   prot_type                                                               */
/*     Field indicating the protocol type.                                   */
/*     Valid values are listed below.                                        */
/*   address                                                                 */
/*       Detailed information about the used protocol:                       */
/*     tcpip                                                                 */
/*       host-name.                                                          */
/*       IP address.                                                         */
/*       port number (internal use)                                          */
/*     sna                                                                   */
/*       profile ->  Name of the SNA profile or                              */
/*                                                                           */
/*       netid  |    Network identifier                                      */
/*       luname |->  LU name                                                 */
/*       lumode |    LU mode                                                 */
/*****************************************************************************/
typedef struct usrx_network_cfg
{
  DC_USHORT    prot_type;
  union
  {
    struct
    {
      DC_CHAR     name[MAX_IP_NAME_LEN];
      DC_CHAR     ipaddr[MAX_IPADDR_LEN];
      DC_USHORT   port;
      DC_USHORT   max_conn;
      DC_USHORT   pad[2];
    } tcpip;

    struct
    {
      DC_CHAR   profile[MAX_SNA_NAME_LEN];
      DC_CHAR   netid[MAX_SNA_NAME_LEN];
      DC_CHAR   luname[MAX_SNA_NAME_LEN];
      DC_CHAR   lumode[MAX_SNA_NAME_LEN];
    } sna;

  } address;

} USRX_NETWORK_CFG;

/*****************************************************************************/
/* Valid protocol type values                                                */
/*****************************************************************************/
#define PROT_TCPIP   1
#define PROT_SNA     2

/*****************************************************************************/
/* Structure: USRX_TARGET_CONFIG                                             */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure defines a Target Configuration record in the NvDM/6000   */
/*   database. This is used to configure all Targets, both local and remote. */
/*                                                                           */
/* Fields:                                                                   */
/*   name                                                                    */
/*     Name of the Target workstation, or of the Target Group.               */
/*   description                                                             */
/*     Descriptive information.                                              */
/*   rr                                                                      */
/*     Contains the rgn (externalized as Network ID for remote targets) and  */
/*     the ren (externalized as Short Name for all targets and groups).      */
/*                                                                           */
/*     Note for RGN.REN NAME                                                 */
/*       If a target rgn (or ren) is 8 character long, there is no           */
/*       room for the '\0' string-terminator character.                      */
/*       Therefore don't use strcpy, strcmp with rgn and ren.                */
/*       Use strcncpy, strncmp instead. You'll get less core dumps.          */
/*       For the same reason, use 8.8%s and not just %s as format            */
/*       string when using the printf() function.                            */
/*   type                                                                    */
/*     Target type: specifies the type of the target (client, server ...).   */
/*     Also indicates whether the record is for a Target or a Group, and     */
/*     whether it is remote. Values listed below.                            */
/*   mode                                                                    */
/*     Target mode. Specified the way of working of target (push             */
/*     or pull), value listed below.                                         */
/*   target_os                                                               */
/*     OS of target (OS/2, AIX, DOS...).                                     */
/*     See fndcotyp.h for valid target_os field values.                      */
/*   pad                                                                     */
/*     field to keep aligned structure to halfword.                          */
/*   cm_window_start                                                         */
/*     Time at which the Agent window starts. This window says when Agent is */
/*     allowed to process Change Management requests. 00:00:00 means that    */
/*     any time before the stop time is OK.                                  */
/*   cm_window_stop                                                          */
/*     Time at which Agent should stop processing new requests,              */
/*     Any value greater than 23:59:59 means there is no stop time.          */
/*   dstn_window_start                                                       */
/*     Time at which Agent may start processing distribution requests,       */
/*     00:00:00 means that any time before the stop time is OK.              */
/*   dstn_window_stop                                                        */
/*     Time at which Agent should stop processing distribution requests.     */
/*     Any value greater than 23:59:59 means there is no stop time.          */
/*   log_level                                                               */
/*     Log level for this Target. Values listed below.                       */
/*   password                                                                */
/*     Target password.                                                      */
/*   srv_name                                                                */
/*     Name of the server of this target.                                    */
/*   lan_addr                                                                */
/*     LAN card burned-in address.                                           */
/*   cust                                                                    */
/*     Customer name.                                                        */
/*   contact                                                                 */
/*     Contact name.                                                         */
/*   contact_phone                                                           */
/*     Contact phone number.                                                 */
/*   manager                                                                 */
/*     Owning manager's name.                                                */
/*   manager_addr                                                            */
/*     Owning manager's mail address.                                        */
/*   network_config                                                          */
/*     The network configuration information about the target                */
/*   num_hw_parm                                                             */
/*     Number of hardware parameters.                                        */
/*   hw_parm                                                                 */
/*     Hardware parameter array.                                             */
/*   num_inst_parm                                                           */
/*     Number of installation parameters.                                    */
/*   inst_parm                                                               */
/*     Installation parameter array.                                         */
/*****************************************************************************/
typedef struct usrx_target_config
{
  DC_CHAR          name[DVA_TRGNAME_LEN];
  DC_CHAR          description[DVA_DESCR_LEN];
  DC_DSU_NAME      rr;
  DC_CHAR          type;
  DC_CHAR          target_os;
  DC_CHAR          mode;
  DC_CHAR          pad;
  DVA_TIME         cm_window_start;
  DVA_TIME         cm_window_stop;
  DVA_TIME         dstn_window_start;
  DVA_TIME         dstn_window_stop;
  DC_CHAR          log_level;
  DC_CHAR          password[DVA_USRNAME2_LEN];
  DC_CHAR          srv_name[DVA_TRGNAME_LEN];
  DC_CHAR          lan_addr[DVA_LANADDR_LEN];
  DC_CHAR          cust[DVA_DESCR_LEN];
  DC_CHAR          contact[DVA_DESCR_LEN];
  DC_CHAR          contact_phone[DVA_PHONE_LEN];
  DC_CHAR          manager[DVA_DESCR_LEN];
  DC_CHAR          manager_addr[DVA_ADDR_LEN];
  USRX_NETWORK_CFG network_config;
  DC_USHORT        num_hw_parm;
  USRX_HW_PARM     hw_parm[DVA_MAX_HW_PARM];
  DC_USHORT        num_inst_parm;
  USRX_INST_PARM   inst_parm[DVA_MAX_INST_PARMS];
} USRX_TARGET_CONFIG;

/*****************************************************************************/
/* Values of type field (may be combined bitwise)                            */
/*****************************************************************************/
#define TARGET_NO_CM     1                   /* Target is not a DACA Target  */
#define CLIENT           2                   /* Target is a Client           */
#define BASE_SYS         4                   /* Target is a Base System      */
#define SERVER           8                   /* Target is a Server           */
#define TARGET_LOCAL    32                   /* Record is for a local target */
#define TARGET_REMOTE  128                   /* Record is for a remote target*/

/*****************************************************************************/
/* Values of mode field                                                      */
/*****************************************************************************/
#define TARGET_PULL     1                    /* Target is a pull mode Target */
#define TARGET_PUSH     2                    /* Target is a push mode Target */
#define TARGET_FOCAL    4                    /* Target works in Manager mode */
#define TARGET_RTFOCAL  8                    /* Target is a Focal Point      */
#define TGT_NO_MODE     16                   /* Target mode for an UI only   */

/*****************************************************************************/
/* Values for log_level field                                                */
/*****************************************************************************/
#define LOG_DIAGNOSTIC      2
#define LOG_NORMAL          1
#define LOG_MINIMAL         0

/*****************************************************************************/
/* Values of window_start and window_stop fields to indicate that the target */
/* target is available for the requests all day or that it is never avilable.*/
/*****************************************************************************/
#define START_ALL_HR    0                       /* start hour for all day    */
#define START_ALL_MN    0                       /* start minute for all day  */
#define START_ALL_SC    0                       /* start second for all day  */
#define STOP_ALL_HR    23                       /* stop hour for all day     */
#define STOP_ALL_MN    59                       /* stop minute for all day   */
#define STOP_ALL_SC    59                       /* stop second for all day   */

#define START_NEV_HR    0                       /* start hour for never      */
#define START_NEV_MN    0                       /* start minute for never    */
#define START_NEV_SC    0                       /* start second for never    */
#define STOP_NEV_HR     0                       /* stop hour for never       */
#define STOP_NEV_MN     0                       /* stop minute for never     */
#define STOP_NEV_SC     0                       /* stop second for never     */

/*****************************************************************************/
/* Structure: USRX_USER_DEF                                                  */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure defines a User record in the DB.                         */
/*                                                                           */
/* Fields:                                                                   */
/*   user                                                                    */
/*     user name                                                             */
/*   description                                                             */
/*     user's description                                                    */
/*   auth_profile                                                            */
/*     name of the authorization profile for this user                       */
/*   all_trg                                                                 */
/*     flag indicating whether the user is allowed to manage all             */
/*     targets TRUE or FALSE                                                 */
/*   excl_trg                                                                */
/*     flag indicating whether the following list is to be                   */
/*     considered as an excluding one: TRUE or FALSE                         */
/*   num_trg                                                                 */
/*     actual number of entries in the target list                           */
/*   target                                                                  */
/*     array containing the list of the target from which user               */
/*     can login                                                             */
/*****************************************************************************/
typedef struct usrx_user_def
{
  DC_CHAR      user[DVA_USRNAME2_LEN];
  DC_CHAR      description[DVA_DESCR_LEN];
  DC_CHAR      auth_profile[DVA_USRNAME2_LEN];
  DC_USHORT    all_trg;
  DC_USHORT    excl_trg;
  DC_USHORT    num_trg;
  TARGET_NAME  target[DVA_MAX_LOGIN_TRGS];
} USRX_USER_DEF;

/*****************************************************************************/
/* Function type applied to a target/user record.                            */
/*****************************************************************************/
#define ADD_CFG      1
#define UPD_CFG      2

DC_SHORT  sx_usrexit_trgcfg(const DC_USHORT     action,
                            const USRX_TARGET_CONFIG  *in_trg_config,
                            USRX_TARGET_CONFIG  *out_trg_config);
/*****************************************************************************/
/* Description: This routine will be called during an add or update command  */
/*              required for a target configuration record.                  */
/*                                                                           */
/*              It can be filled by user code, to set default value of a     */
/*              target configuration record.                                 */
/*              The fields which the product will consider are:              */
/*                                                                           */
/*              - description      : Descriptive information.                */
/*              - target_os        : OS of target (OS/2, AIX, DOS...).       */
/*              - password         : Target password.                        */
/*              - lan_addr         : LAN card burned-in address.             */
/*              - cust             : Customer name.                          */
/*              - contact          : Contact name.                           */
/*              - contact_phone    : Contact phone number.                   */
/*              - manager          : Owning manager's name.                  */
/*              - manager_addr     : Owning manager's mail address.          */
/*              - num_hw_parm      : Number of hardware parameters.          */
/*              - hw_parm          : Hardware parameter array.               */
/*              - num_inst_parm    : Number of installation parameters.      */
/*              - inst_parm        : Installation parameter array.           */
/*                                                                           */
/*                                                                           */
/* Parameters:                                                               */
/*              action         : ADD_CFG or UPD_CFG according to the         */
/*                               executing command.                          */
/*              in_trg_config  : input structure of target configuration     */
/*                               record.                                     */
/*              out_trg_config : output structure of target configuration    */
/*                               record which can be filled with user-exit   */
/*                               default values.                             */
/*                                                                           */
/* Returns:     0   : Successfull completion                                 */
/*                                                                           */
/*****************************************************************************/

DC_SHORT  sx_usrexit_usrcfg(const DC_USHORT      action,
                            const USRX_USER_DEF  *in_usr_def,
                            USRX_USER_DEF *out_usr_def);
/*****************************************************************************/
/* Description: This routine will be called during an add or update command  */
/*              required for a user configuration record.                    */
/*                                                                           */
/*              It can be filled by user code, to set default value of a     */
/*              user configuration record.                                   */
/*              The fields which the product will consider are:              */
/*                                                                           */
/*              - description      : Descriptive information.                */
/*                                                                           */
/*                                                                           */
/* Parameters:                                                               */
/*              action         : ADD_CFG or UPD_CFG according to the         */
/*                               executing command.                          */
/*              in_usr_def     : input structure of user configuration       */
/*                               record.                                     */
/*              out_usr_def    : output structure of user configuration      */
/*                               record which can be filled with user-exit   */
/*                               default values.                             */
/*                                                                           */
/* Returns:     0   : Successfull completion                                 */
/*                                                                           */
/*****************************************************************************/
/* fndsx.h */
